package org.apache.bcel.classfile;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import org.apache.bcel.classfile.Attribute;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.Utility;
import org.apache.bcel.classfile.Visitor;
import org.apache.commons.lang3.ArrayUtils;

public final class ModulePackages extends Attribute {
  private int[] packageIndexTable;
  
  ModulePackages(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
    this(nameIndex, length, (int[])null, constantPool);
    int packageCount = input.readUnsignedShort();
    this.packageIndexTable = new int[packageCount];
    for (int i = 0; i < packageCount; i++)
      this.packageIndexTable[i] = input.readUnsignedShort(); 
  }
  
  public ModulePackages(int nameIndex, int length, int[] packageIndexTable, ConstantPool constantPool) {
    super((byte)23, nameIndex, length, constantPool);
    this.packageIndexTable = (packageIndexTable != null) ? packageIndexTable : ArrayUtils.EMPTY_INT_ARRAY;
  }
  
  public ModulePackages(org.apache.bcel.classfile.ModulePackages c) {
    this(c.getNameIndex(), c.getLength(), c.getPackageIndexTable(), c.getConstantPool());
  }
  
  public void accept(Visitor v) {
    v.visitModulePackages(this);
  }
  
  public Attribute copy(ConstantPool constantPool) {
    org.apache.bcel.classfile.ModulePackages c = (org.apache.bcel.classfile.ModulePackages)clone();
    if (this.packageIndexTable != null)
      c.packageIndexTable = (int[])this.packageIndexTable.clone(); 
    c.setConstantPool(constantPool);
    return c;
  }
  
  public void dump(DataOutputStream file) throws IOException {
    super.dump(file);
    file.writeShort(this.packageIndexTable.length);
    for (int index : this.packageIndexTable)
      file.writeShort(index); 
  }
  
  public int getNumberOfPackages() {
    return (this.packageIndexTable == null) ? 0 : this.packageIndexTable.length;
  }
  
  public int[] getPackageIndexTable() {
    return this.packageIndexTable;
  }
  
  public String[] getPackageNames() {
    String[] names = new String[this.packageIndexTable.length];
    Arrays.setAll(names, i -> Utility.pathToPackage(getConstantPool().getConstantString(this.packageIndexTable[i], (byte)20)));
    return names;
  }
  
  public void setPackageIndexTable(int[] packageIndexTable) {
    this.packageIndexTable = (packageIndexTable != null) ? packageIndexTable : ArrayUtils.EMPTY_INT_ARRAY;
  }
  
  public String toString() {
    StringBuilder buf = new StringBuilder();
    buf.append("ModulePackages(");
    buf.append(this.packageIndexTable.length);
    buf.append("):\n");
    for (int index : this.packageIndexTable) {
      String packageName = getConstantPool().getConstantString(index, (byte)20);
      buf.append("  ").append(Utility.compactClassName(packageName, false)).append("\n");
    } 
    return buf.substring(0, buf.length() - 1);
  }
}
